[clang] [clang-repl] Fix RuntimeInterfaceBuilder for 32-bit systems (PR #97071)

Stefan Gränitz via cfe-commits cfe-commits at lists.llvm.org
Fri Jun 28 08:21:42 PDT 2024


https://github.com/weliveindetail created https://github.com/llvm/llvm-project/pull/97071

When generating runtime interface bindings, extend integral types to the native register size rather than 64-bit per se

>From ca2ab5f9e3470e87923c7b950b7b06e5ff21119e Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Stefan=20Gr=C3=A4nitz?= <stefan.graenitz at gmail.com>
Date: Fri, 28 Jun 2024 16:43:42 +0200
Subject: [PATCH] [clang-repl] Fix RuntimeInterfaceBuilder for 32-bit systems

When generating runtime interface bindings, extend integral types to the native register size rather than 64-bit per se
---
 clang/lib/Interpreter/Interpreter.cpp | 8 +++++---
 1 file changed, 5 insertions(+), 3 deletions(-)

diff --git a/clang/lib/Interpreter/Interpreter.cpp b/clang/lib/Interpreter/Interpreter.cpp
index 7a95278914276..e6d6ab6024bb8 100644
--- a/clang/lib/Interpreter/Interpreter.cpp
+++ b/clang/lib/Interpreter/Interpreter.cpp
@@ -673,10 +673,12 @@ class InterfaceKindVisitor
   }
 
 private:
   // Force cast these types to uint64 to reduce the number of overloads of
   // `__clang_Interpreter_SetValueNoAlloc`.
   void HandleIntegralOrEnumType(const Type *Ty) {
-    TypeSourceInfo *TSI = Ctx.getTrivialTypeSourceInfo(Ctx.UnsignedLongLongTy);
+    uint64_t PtrBits = Ctx.getTypeSize(Ctx.VoidPtrTy);
+    QualType UIntTy = Ctx.getBitIntType(true, PtrBits);
+    TypeSourceInfo *TSI = Ctx.getTrivialTypeSourceInfo(UIntTy);
     ExprResult CastedExpr =
         S.BuildCStyleCastExpr(SourceLocation(), TSI, SourceLocation(), E);
     assert(!CastedExpr.isInvalid() && "Cannot create cstyle cast expr");
@@ -673,10 +673,12 @@ class InterfaceKindVisitor
 
 private:
-  // Force cast these types to uint64 to reduce the number of overloads of
-  // `__clang_Interpreter_SetValueNoAlloc`.
+  // Force cast these types to the uint that fits the register size. That way we
+  // reduce the number of overloads of `__clang_Interpreter_SetValueNoAlloc`.
   void HandleIntegralOrEnumType(const Type *Ty) {



More information about the cfe-commits mailing list